ProofRpcClient

Trait ProofRpcClient 

pub trait ProofRpcClient: ClientT {
    // Provided methods
    fn health<'life0, 'async_trait>(
        &'life0 self,
    ) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>
       where Self: Sync + 'async_trait,
             'life0: 'async_trait { ... }
    fn checkpoint_proof<'life0, 'async_trait>(
        &'life0 self,
        blober: PubkeyFromStr,
        slot: u64,
        customer_elf: CustomerElf,
    ) -> Pin<Box<dyn Future<Output = Result<String, Error>> + Send + 'async_trait>>
       where Self: Sync + 'async_trait,
             'life0: 'async_trait { ... }
    fn get_proof_request_status<'life0, 'async_trait>(
        &'life0 self,
        request_id: String,
    ) -> Pin<Box<dyn Future<Output = Result<RequestStatus, Error>> + Send + 'async_trait>>
       where Self: Sync + 'async_trait,
             'life0: 'async_trait { ... }
}
Client implementation for the ProofRpc RPC API.

Provided Methods

fn health<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

Check the health of the RPC server. Returns an error if the server is not healthy.

fn checkpoint_proof<'life0, 'async_trait>( &'life0 self, blober: PubkeyFromStr, slot: u64, customer_elf: CustomerElf, ) -> Pin<Box<dyn Future<Output = Result<String, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

Request building a succinct ZK Groth16 proof for a given blober and slot. (Custom per client)

fn get_proof_request_status<'life0, 'async_trait>( &'life0 self, request_id: String, ) -> Pin<Box<dyn Future<Output = Result<RequestStatus, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

Get a proof request status by its ID. Returns an error if the request does not exist or if there was a database or RPC failure.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<TypeJsonRpseeInteral> ProofRpcClient for TypeJsonRpseeInteral
where TypeJsonRpseeInteral: ClientT,