pub trait ProofRpcServer:
Sized
+ Send
+ Sync
+ 'static {
// Required methods
fn health<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = RpcResult<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn checkpoint_proof<'life0, 'async_trait>(
&'life0 self,
blober: PubkeyFromStr,
slot: u64,
customer_elf: CustomerElf,
) -> Pin<Box<dyn Future<Output = RpcResult<String>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn get_proof_request_status<'life0, 'async_trait>(
&'life0 self,
request_id: String,
) -> Pin<Box<dyn Future<Output = RpcResult<RequestStatus>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
// Provided method
fn into_rpc(self) -> RpcModule<Self> { ... }
}Expand description
Server trait implementation for the ProofRpc RPC API.
Required Methods
Sourcefn health<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = RpcResult<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn health<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = RpcResult<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Check the health of the RPC server. Returns an error if the server is not healthy.
Sourcefn checkpoint_proof<'life0, 'async_trait>(
&'life0 self,
blober: PubkeyFromStr,
slot: u64,
customer_elf: CustomerElf,
) -> Pin<Box<dyn Future<Output = RpcResult<String>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn checkpoint_proof<'life0, 'async_trait>(
&'life0 self,
blober: PubkeyFromStr,
slot: u64,
customer_elf: CustomerElf,
) -> Pin<Box<dyn Future<Output = RpcResult<String>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Request building a succinct ZK Groth16 proof for a given blober and slot. (Custom per client)
Sourcefn get_proof_request_status<'life0, 'async_trait>(
&'life0 self,
request_id: String,
) -> Pin<Box<dyn Future<Output = RpcResult<RequestStatus>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_proof_request_status<'life0, 'async_trait>(
&'life0 self,
request_id: String,
) -> Pin<Box<dyn Future<Output = RpcResult<RequestStatus>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Get a proof request status by its ID. Returns an error if the request does not exist or if there was a database or RPC failure.
Provided Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".